This is a very simple component with no configuration options. It is used for helping student keep track of what portion of a course they've completed. For example, you might place this underneath each text and video component, and students can see in their progress page which portions are completed and which still need to be watched or read.

It is also helpful to give students a way to sign off on having completed something. They are less likely to skip material that way.

(If you're a real power-user, in OLX, we do allow you to add an align tag, which can left-, center-, or right-justify the XBlock)